# -*- coding: utf-8 -*-

from rest_framework import serializers

from ... import models
from thx.api.serializers import (
    ThuxListSerializerMixin, ThuxRetrieveSerializerMixin, ThuxCreateSerializerMixin,
    ThuxUpdateSerializerMixin, ThuxPartialUpdateSerializerMixin, ThuxStatusSerializerMixin,
    ThuxEnableSerializerMixin, ThuxDisableSerializerMixin
)
from thx.role.core.serializers import ThuxRoleSerializerMixin


# JOB
class JobSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_cron_job'
        model = models.Job
        fields = '__all__'


class JobListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_cron_job_list'
        model = models.Job
        fields = '__all__'


class JobRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_cron_job_retrieve'
        model = models.Job
        fields = '__all__'


class JobCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_cron_job_create'
        model = models.Job
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def to_representation(self, instance):
        return JobListSerializer(instance, context=self.context).data


class JobUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_cron_job_update'
        model = models.Job
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def to_representation(self, instance):
        return JobRetrieveSerializer(instance, context=self.context).data


class JobPartialUpdateSerializer(
    ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_cron_job_partial_update'
        model = models.Job
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def to_representation(self, instance):
        return JobRetrieveSerializer(instance, context=self.context).data


class JobEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_cron_job_enable'
        model = models.Job
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    def to_representation(self, instance):
        return JobRetrieveSerializer(instance, context=self.context).data


class JobDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_cron_job_disable'
        model = models.Job
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    def to_representation(self, instance):
        return JobRetrieveSerializer(instance, context=self.context).data


# JOB LOG
class JobLogSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_cron_job_log'
        model = models.JobLog
        fields = '__all__'


class JobLogListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_cron_job_log_list'
        model = models.JobLog
        fields = '__all__'


class JobLogRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_cron_job_log_retrieve'
        model = models.JobLog
        fields = '__all__'


class JobLogEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_cron_job_log_enable'
        model = models.JobLog
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    def to_representation(self, instance):
        return JobLogRetrieveSerializer(instance, context=self.context).data


class JobLogDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_cron_job_log_disable'
        model = models.JobLog
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    def to_representation(self, instance):
        return JobLogRetrieveSerializer(instance, context=self.context).data
