# -*- coding: utf-8 -*-

"""
CronAlertEmailBackend
===============

Questo Backend eredita da CronAlertBackendMixin e notifica le utenze indicate inviando un'email.

Classi
========

.. autoclass:: CronAlertEmailBackend
   :members:

"""
from django.conf import settings
from django.core.mail import send_mail
from django.template.loader import render_to_string

from .mixins import CronAlertBackendMixin


def load_cron_alert_email_config() -> dict:
    data = settings.CRON_ALERT_EMAIL_BACKEND_CONFIG
    data.setdefault("fail_silently", False)
    data.setdefault("from_email", None)
    data.setdefault("recipient_list", [])
    data.setdefault("email_template", "thx/cron/alert/cron_alert_default_template.html")
    data.setdefault("text_template", "thx/cron/alert/cron_alert_default_template.txt")
    return data


class CronAlertEmailBackend(CronAlertBackendMixin):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.email_config = load_cron_alert_email_config()
        self.text_template_path = self.email_config["text_template"]
    
    def send_alert(self):
        return send_mail(
            subject=self.get_subject(),
            message=self.get_text_message(),
            html_message=self.get_html_message(),
            from_email=self.email_config['from_email'],
            recipient_list=self.email_config['recipient_list'],
            fail_silently=self.email_config['fail_silently'],
        )

    def get_subject(self):
        return "CRON JOB ALERT"

    def get_html_message(self):
        html_template_path = self.email_config.get('email_template', None)
        if html_template_path:
            return render_to_string(html_template_path, self.job.__dict__)
